@@ -291,8 +291,22 @@ public class AddrView : Gtk.Table {
 		tg = new Gtk.CheckButton("working set");
 		tg.Active = this.viewWorkingSet;
 		tg.Toggled += delegate {
-			this.viewWorkingSet = tg.Active;
-			ZoomFitWindow ();
+            Console.WriteLine ("do we have thunks ? " + sd.Thunks.Count);
+            if (tg.Active && sd.HasNoThunks) {
+                Gtk.MessageDialog error;
+                error = new Gtk.MessageDialog (null, Gtk.DialogFlags.Modal,
+                                               Gtk.MessageType.Warning,
+                                               Gtk.ButtonsType.Ok, true,
+                                               "<b>Error</b> - the trace you generated doesn't seem to contain working set " +
+                                               " information - please re-capture the trace with --enable-working-set=yes");
+                error.DeleteEvent += delegate { error.Destroy(); };
+                error.Response += delegate { error.Destroy(); };
+                error.ShowAll();
+                tg.Active = false;
+            } else {
+                this.viewWorkingSet = tg.Active;
+                ZoomFitWindow ();
+            }
 		};
 		box.PackStart (tg, false, false, 0);
 
