@@ -290,6 +290,9 @@ public class SimulationData {
         get { return this.TotalTime; }
     }
 
+    public bool HasNoThunks {
+        get { return Thunks.Count <= 2; }
+    }
     public List<SimEvent> Thunks;
     public void AddThunk (SimEvent thunk)
     {
@@ -459,7 +462,6 @@ public class SimProcess
             // FIXME: chain to simulatePageTouch for address 'be.Start' ...
             break;
         }
-
         case IOEventType.WriteBlock: {
             BlockEvent be = (BlockEvent) ioe;
             this.fsModel.Write (sime, ioe.FileHandle, be.Start, be.Length);
@@ -471,6 +473,9 @@ public class SimProcess
             this.fsModel.ReadAhead (sime, ioe.FileHandle, be.Start, be.Length);
             break;
         }
+        case IOEventType.FSync:
+            this.fsModel.FSync (sime, ioe.FileHandle);
+            break;
         default:
             Console.WriteLine ("Unknown I/O event " + ioe.Type + " to simulate... ");
             break;
@@ -688,11 +693,11 @@ public class Simulator
         }
 	}
 
-    List<SimProcess> procs;
-
 	public SimulationData Simulate (Trace.Data td)
 	{
-        this.procs = new List<SimProcess>();
+		List<SimProcess> procs;
+
+        procs = new List<SimProcess>();
         int numAlive = 0;
 
         foreach (Process tp in td.Processes) {
@@ -700,7 +705,7 @@ public class Simulator
             // FIXME: need to have 'exec' hintsto defer Runnable ...
             sp.State = ProcessState.Runnable;
             numAlive++;
-            this.procs.Add (sp);
+            procs.Add (sp);
         }
 
         // We implement all this with threads, to make the various
